@@ -12,7 +12,7 @@ def convert(estimator, kind=None, method='pymodule', dtype='float'):
         kind = type(estimator).__name__
 
     # Use name instead of instance to avoid hard dependency on the libraries
-    if kind in ['RandomForestClassifier', 'ExtraTreesClassifier', 'DecisionTreeClassifier']:
+    if kind in set(trees.SUPPORTED_ESTIMATORS):
         return trees.Wrapper(estimator, method, dtype=dtype)
     elif kind in ['EllipticEnvelope']:
         return distance.Wrapper(estimator, method, dtype=dtype)
